:github_url: https://github.com/tasts-robots/pink/tree/master/doc/src/forward-kinematics.rst

.. _Forward kinematics:

******************
Forward kinematics
******************

.. automodule:: pink.configuration
    :members:
